import {
    shopTypeList,
    shopDiy
} from '@/api/product'

import { usePaging } from '@/hooks/usePaging'
import feedback from '@/utils/feedback'
import { ElMessage, ElTree, type CheckboxValueType } from 'element-plus'
import { shallowRef, type Ref } from 'vue'
import useAppStore from '@/stores/modules/app'

const appStore = useAppStore()

// 左侧分组的钩子函数
export function useCate(type: number) {
    const treeRef = shallowRef<InstanceType<typeof ElTree>>()
    // 分组列表
    const cateLists = ref<any[]>([])

    // 选中的分组id
    const cateId = ref<number | string>('')

    // 获取分组列表
    const getCateLists = async () => {
        const res = await shopTypeList({ type: 1 })
        const item: any[] = [
            {
                title: '全部',
                id: ''
            }
        ]

        cateLists.value = res.data.list;
        cateLists.value.unshift(...item)
        setTimeout(() => {
            treeRef.value?.setCurrentKey(cateId.value)
        }, 0)
    }


    //选中分类
    const handleCatSelect = (item: any) => {
        cateId.value = item.id
    }

    return {
        treeRef,
        cateId,
        cateLists,
        getCateLists,
        handleCatSelect
    }
}


// 处理文件的钩子函数
export function useFile(
    cateId: Ref<string | number>,
    type: Ref<number>,
    limit: Ref<number>,
    size: number
) {
    const tableRef = shallowRef()
    const listShowType = ref('normal')
    const moveId = ref(0)
    const select = ref<any[]>([])
    const isCheckAll = ref(false)
    const isIndeterminate = ref(false)

    const fileParams = reactive({
        content: '',
        tid: cateId
    })

    const { pager, getLists, resetPage } = usePaging({
        fetchFun: shopDiy,
        params: fileParams,
        firstLoading: true,
        size
    })

    const getFileList = () => {
        getLists()
    }
    const refresh = () => {
        resetPage()
    }

    const isSelect = (id: number) => {
        return !!select.value.find((item: any) => item.id == id)
    }


    const selectFile = (item: any) => {
        const index = select.value.findIndex((items: any) => items.id == item.id)
        if (index != -1) {
            select.value.splice(index, 1)
            return
        }
        if (select.value.length == limit.value) {
            if (limit.value == 1) {
                select.value = []
                select.value.push(item)
                return
            }
            ElMessage.warning('已达到选择上限')
            return
        }
        select.value.push(item)
    }

    const clearSelect = () => {
        select.value = []
    }

    const cancelSelete = (id: number) => {
        select.value = select.value.filter((item: any) => item.id != id)
    }

    const selectAll = (value: CheckboxValueType) => {
        isIndeterminate.value = false
        tableRef.value?.toggleAllSelection()
        if (value) {
            select.value = [...pager.lists]
            return
        }
        clearSelect()
    }

    return {
        listShowType,
        tableRef,
        moveId,
        pager,
        fileParams,
        select,
        isCheckAll,
        isIndeterminate,
        getFileList,
        refresh,
        selectFile,
        isSelect,
        clearSelect,
        cancelSelete,
        selectAll
    }
}
